Changelog
=========

0.5.3 - 2017-04-08
------------------

* Implement Secure Password Reset (dcb1487_)

.. _dcb1487: https://github.com/level12/keg-login/commit/dcb1487


0.5.2 - 2016-12-06
------------------

* Allow configuration of remember button (0d263a4_)

.. _0d263a4: https://github.com/level12/keg-login/commit/0d263a4


 - 2016-11-11
------------------

* Merge pull request #8 from level12/keg-elements-form-level-validation (7ae0c95_)
* Merge pull request #5 from level12/gh-2-multiple-template-bases (b24de25_)
* Merge pull request #6 from level12/gh-3-package-level-imports (d3eb6b8_)
* Merge pull request #7 from level12/gh-4-flask.ext-deprecation (ca005a5_)

.. _7ae0c95: https://github.com/level12/keg-login/commit/7ae0c95
.. _b24de25: https://github.com/level12/keg-login/commit/b24de25
.. _d3eb6b8: https://github.com/level12/keg-login/commit/d3eb6b8
.. _ca005a5: https://github.com/level12/keg-login/commit/ca005a5

